/* 	Estimation and graphing commands accompanying "The Effect of Chronic Wasting 
	Disease on Resident Deer Hunting Permit Demand in Wisconsin" by Dane Erickson, 
	Carson Reeling, and John Lee, Department of Agricultural Economics, Purdue 
	University. */


clear
graph drop _all

* Load data (change filepath as needed)-----------------------------------------
use "WI_Deer_Permit_Sales_Data.dta"


* Generate regression variables-------------------------------------------------
gen CPI_2012 = CPI/CPI[47]*100
gen q_total = q_gun + q_bow											/* Agg. permit demand */
gen p_gun_real = p_gun/(CPI_2012/100)								/* Real price of gun permit */
gen p_bow_real = p_bow/(CPI_2012/100)								/* Real price of bow permit */
gen p = p_gun_real*(q_gun/q_total) + p_bow_real*(q_bow/q_total)		/* Mean resident permit price */
gen lnq_bow = ln(q_bow)
gen lnq_gun = ln(q_gun)
gen proportion_r = rLTPS/(rLTPS + nrLTPS)							/* Proportion of licenses, permits, tags, stamps sold to residents */
gen q_total_r = q_total*proportion_r								/* Total resident deer permit sales */
gen q_bow_r = q_bow*proportion_r									/* Resident archery deer permit sales */
gen q_gun_r = q_gun*proportion_r									/* Resident gun deer permit sales */
gen lnq_r = ln(q_total_r)
gen lnq_gun_r = ln(q_gun_r)
gen lnq_bow_r = ln(q_bow_r)
gen inc_reap0000 = inc_reap/10000									/* Income ($10,000) */
gen pop_mil = pop/1000000											/* Wisconsin population (millions) */
gen year2 = year^2
gen CWDyear = year*CWD
gen CWDyear2 = year2*CWD


* Run regression models---------------------------------------------------------
reg lnq_r p inc_reap0000 CWD year year2, r 							/* Model 1 */
reg lnq_r p inc_reap0000 CWD year year2 pop_mil, r 					/* Model 2 */
reg lnq_gun_r p_gun_real inc_reap0000 CWD year year2, r				/* Model 3 */
reg lnq_bow_r p_bow_real inc_reap0000 CWD year year2, r				/* Model 4 */
reg lnq_r p inc_reap0000 i.CWD##c.year, r 							/* Model 5 */
reg lnq_r p inc_reap0000 year year2 CWD CWDyear2, r 				/* Model 6 */			


* Simulate demand with and without CWD------------------------------------------
* Model 1
quietly reg lnq_r p inc_reap0000 year year2 CWD
predict lnq_CWD_1
gen q_CWD_1 = exp(lnq_CWD_1)/1000000

gen lnq_No_CWD_1 = _b[_cons]+_b[p]*p+_b[inc_reap0000]*inc_reap0000+_b[year]*year+_b[year2]*year2 
gen q_No_CWD_1 = exp(lnq_No_CWD_1)/1000000

*Model 5
quietly reg lnq_r p inc_reap0000 CWD year CWDyear
predict lnq_CWD_5
gen q_CWD_5 = exp(lnq_CWD_5)/1000000

gen lnq_No_CWD_5 = _b[_cons]+_b[p]*p+_b[inc_reap0000]*inc_reap0000+_b[year]*year
gen q_No_CWD_5 = exp(lnq_No_CWD_5)/1000000

* Model 6
quietly reg lnq_r p inc_reap0000 year year2 CWD CWDyear2
predict lnq_CWD_6
gen q_CWD_6 = exp(lnq_CWD_6)/1000000

gen lnq_No_CWD_6 = _b[_cons]+_b[p]*p+_b[inc_reap0000]*inc_reap0000+_b[year]*year+_b[year2]*year2
gen q_No_CWD_6 = exp(lnq_No_CWD_6)/1000000

gen q_total_r_000 = q_total_r/1000000

* Plot estimated demand vs real demand
line q_CWD_1 q_No_CWD_1 year, ytitle("Resident license demand (mil.)", size(large) margin(small)) ///
	ylabel(.500(.100).950,labsize(large) )	xtitle("Year", size(large)) xlabel(1960(20)2020,labsize(large)) ///
	legend(order(1 "Demand with CWD" 2 "Demand without CWD" ) size(large) region(col(white))) ///
	lpattern( - l) lcolor( black black) graphregion(color(white)) ///
	bgcolor(white) name(demand1) xsize(6.5) legend(off)
	
line q_CWD_5 q_No_CWD_5  year, ytitle("Resident license demand (mil.)", size(large) margin(small)) ylabel(.500(.100)1.250,labsize(large)) ///
	xtitle("Year", size(large)) xlabel(1960(20)2020,labsize(large)) lpattern( - l) lcolor( black black ) ///
	graphregion(color(white)) bgcolor(white) name(demand5) legend(off) xsize(6.5) 
	
line q_CWD_6 q_No_CWD_6  year, ytitle("Resident license demand (mil.)", size(large) margin(small)) ylabel(.500(.100).950,labsize(large) ) ///
	xtitle("Year", size(large)) xlabel(1960(20)2020,labsize(large)) lpattern( - l) lcolor( black black ) ///
	graphregion(color(white)) bgcolor(white) name(demand6) legend(off) xsize(6.5) 
	
	
* Calculate lost hunter surplus, license expenditures/revenues (Model 1 only)
quietly reg lnq_r p inc_reap0000 year year2 CWD
gen s_loss_CWD_r = -1/_b[p]*(q_No_CWD_1 - q_CWD_1)
gen rev_loss_r = p_gun_real*(q_No_CWD_1 - q_CWD_1)
line s_loss_CWD_r rev_loss_r year if year >=2002, ytitle("$ million") lcolor(black black) ///
	graphregion(color(white)) bgcolor(white) lpattern (- l) ///
	legend(order(1 "Lost hunter surplus" 2 "Lost permit expenditures"))  ///
	name(surplus_abs) xlabel(2002(2)2015)

* Calculate the effect of time on hunter surplus (Model 1 only)
gen margt = 1/_b[p]*(exp(_b[CWD])-1)*(_b[year]+2*_b[year2]*year)*q_No_CWD_1*1000000
line margt year if year >=2002, ytitle("$") lcolor(black) ///
	graphregion(color(white)) bgcolor(white) lpattern (l) ///
	legend(order(1 "Lost hunter surplus" 2 "Lost permit expenditures"))  ///
	name(margt) xlabel(2002(2)2015)
